% Regional multipliers calculations with loacl autonomy
% codes based on codes of Emi Nakamura and Jon Steinsson -- Oct 2010
% economy with capital, variable utilization and GHH preferences
% sensitivity online appendix Figure C.4
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%clear all;close all;
period = 10; % specify number of period
NIR = period;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calibration of parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
beta = 0.96;     % Subjective discount factor
sigma = 1;       % Intertemporal elastisity of substitution
nu = 1;          % Frish elasticity of labor suppy
aa = 0.7;        % Curvature of production function
theta = 6;       % Elasticity of substitution between varieties
delta = 0.06;    % Rate of depreciation of capital
sigma_a = 1.1;   % Elasticity of capital utilization cost
kappa_i = 0.1;   % investment adjustment cost parameter

% sensitivity parameters
eta = 4;%        % Elasticity of substitution between home and foreign goods
alpha = 0.32;    % Calvo parameter
nn = 0.08;       % Size of home region
phiH = 0.66;     % Weight of home goods in home consumption basket
phiF = 1-phiH;   % Weight of foreign goods in home consumption basket
phiHstar = phiF*nn/(1-nn);  % Weight of home goods in foreign consumption basket
phiFstar = 1 - phiHstar;    % Weight of foreign goods in foreign consumption basket

if ((min([phiH, phiF, phiHstar, phiFstar]) < 0) || (max([phiH, phiF, phiHstar, phiFstar]) > 1))
    fprintf('Home Bias Error\n')
    fprintf('phiH     = %5.5f\n',phiH)
    fprintf('phiF     = %5.5f\n',phiF)
    fprintf('phiHstar = %5.5f\n',phiHstar)
    fprintf('phiFstar = %5.5f\n',phiFstar)
    error('Home Bias Error')
end
% Government parameters
xsi = 0.28;
Gbar = 0.23;
Gcentralbar = (1-xsi)*Gbar;
% sensitivity pssi;
pssi = -0.5:0.5:0.5;
mou = 0.2; % productivity of public good
omega = 1; % inefifciency of central governemnt
%
%
phiPi = 1.5;     % Inflation response in Taylor Rule
phiY  = 0.0;     % Output response in Taylor Rule
rhoii = 0.95;     % Lagged dependence in Taylor Rule
phiG  = 0.0;    % Direct response of monetary policy to fiscal shock

rhoG = 0.87;%1;      % Persistence of government spending shock
corrG = 0.0;       % Correlation of home and foreign gov spending shocks
%%%%%%%% range for relationship local autonomy -multipliers %%%%%%%%
lamda = 0.0:0.05:1;

% initialise matrices to store multipliers 
SENS_reg_imp=zeros(length(pssi),length(lamda));
SENS_union_imp=zeros(length(pssi),length(lamda));
SENS_reg_cum=zeros(length(pssi),length(lamda));
SENS_union_cum=zeros(length(pssi),length(lamda));
SENS_reg_NS=zeros(length(pssi),length(lamda));
SENS_union_NS=zeros(length(pssi),length(lamda));
SENS_reg_cumk = zeros(length(pssi),length(lamda));
SENS_union_cumk = zeros(length(pssi),length(lamda));
SENS_reg_impk = zeros(length(pssi),length(lamda));
SENS_union_impk = zeros(length(pssi),length(lamda));

for ik=1:length(pssi)
    
KoverL = ((1-aa)*(beta/(1-beta*(1-delta)))*(theta-1)/theta)^(1/aa);
Ibar   = delta*KoverL^aa; % Steady state investment-output ratio
Cbar = 1 - Gbar -Gcentralbar - Ibar; % Steady state consumption-output ratio

kappa    = (1-alpha)*(1-alpha*beta)/alpha;
psi_v    = aa*(1/nu)/(1+(1/nu)*(1-aa));
zeta     = 1/(1+psi_v*theta);
sigma_c  = sigma^(-1)*(1-aa*((theta-1)/theta)*Cbar^(-1)*(1+1/nu)^(-1))^(-1);
sigma_l  = (Cbar^(-1)*((theta-1)/theta)*aa*sigma_c^(-1))^(-1);
psi_c    = aa/(1+(1/nu)*(1-aa));
psi_k    = ((1/nu)+1)*(1-aa)/(1+(1/nu)*(1-aa));
%

for ij=1:length(lamda)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Choose Fiscal Policy
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
NoTaxes             = 1;
BalancedBudget      = 0;

% Steady state taxes
if NoTaxes == 1
    taubar = 0;
end
if BalancedBudget == 1
    taubar = theta/(theta-1)*Gbar; 
end

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Definition of system
%
% g0*x(t)=g1*x(t-1)+C+Psi*z(t)+Pi*eta(t)
% 
% x_(t)= [
%  [1]    c_t
%  [2]    E_t c_t+1
%  [3]    c*_t
%  [4]    E_t c*_t+1
%  [5]    piH_t
%  [6]    E_t piH_t+1
%  [7]    piF_t
%  [8]    E_t piF_t+1
%  [9]    pi_t
%  [10]    E_t pi_t+1
%  [11]    pi*_t
%  [12]    E_t pi*_t+1
%  [13]    y_t
%  [14]   y*_t
%  [15]   q_t
%  [16]   pH_t
%  [17]   r_nt  (nominal interest rate)
%  [18]   g_Ht
%  [19]   g_Ft
%  [20]   ny_t
%  [21]   ny*_t
%  [22]   L_t
%  [23]   L*_t
%  [24]   w_t - p_Ht (real wage with PPI as deflator)
%  [25]   w*_t - p_Ft + q_t (NB: p_Ft = -(phiH/phiF)p_Ht)
%  [26]   s_t + p_Ht (real MC with PPI as deflator)
%  [27]   s*_t + p_Ft 
%  [28]   kbar_t+1 (home installed capital)
%  [29]   kbar*_t+1 
%  [30]   k_t (home capital input (as oppose to installed capital))
%  [31]   k*_t 
%  [32]   i_t (home investment)
%  [33]   i*_t
%  [34]   u_t (home capital utilization)
%  [35]   u*_t
%  [36]   d_t (home shadow value of installed capital)
%  [37]   d*_t
%  [38]   r_kt (home  capital rental rate)
%  [39]   E_t d_t+1
%  [40]   E_t d*_t+1
%  [41]   E_t r_kt+1
%  [42]   r*_kt
%  [43]   E_t r*_kt+1
%  [44]   E_t u_t+1
%  [45]   E_t u*_t+1
%  [46]   E_t L_t+1
%  [47]   E_t L*_t+1
%  [48]   E_t i_t+1
%  [49]   E_t i*_t+1
%  [50]   tau_t
%  [51]   yg local public good
%  [52]   ygs foreign local public good
%  [53]   Gc central governemtn spending
%  [54]   private capital per hour
%  [55]   private capital per hour
%
dimg0 = 55;
cc = zeros(dimg0,1);
g0 = zeros(dimg0,dimg0);
g1 = zeros(dimg0,dimg0);
pi = zeros(dimg0,16);  % Expectational Errors
psi = zeros(dimg0,3); % Disturbances

% Home Consumption Euler Equation
g0(1,1) = -1;
g0(1,2) = 1;
g0(1,22) = sigma_c*sigma_l^(-1);
g0(1,46) = -sigma_c*sigma_l^(-1);
g0(1,17) = -sigma_c;
g0(1,10) = sigma_c;

% Backus-Smith Condition
g0(2,1) = 1;
g0(2,3) = -1;
g0(2,22) = -sigma_c*sigma_l^(-1);
g0(2,23) = sigma_c*sigma_l^(-1);
g0(2,15) = -sigma_c;

% Home Phillips Curve
g0(3,5) = -1;
g0(3,6) = beta;
g0(3,13) = kappa*zeta*psi_v;
g0(3,16) = -kappa*zeta;
g0(3,38) = kappa*zeta*psi_k;
%
g0(3,50) = psi_c*taubar/(1-taubar)*kappa*zeta;
g1(3,51) = kappa*zeta*mou*psi_c*((1/nu)+1)/aa; % corrected 7_5_20


% Foreign Phillips Curve
g0(4,7) = -1;
g0(4,8) = beta;
g0(4,14) = kappa*zeta*psi_v;
g0(4,15) = kappa*zeta*psi_c;
g0(4,16) = phiH/phiF*kappa*zeta;
g0(4,42) = kappa*zeta*psi_k;
g0(4,50) = psi_c*taubar/(1-taubar)*kappa*zeta;
g1(4,52) = kappa*zeta*mou*psi_c*((1/nu)+1)/aa; % corrected 7_5_20

% Home Inflation
g0(5,9) = -1;
g0(5,5) = phiH;
g0(5,7) = phiF;

% Foreign Inflation
g0(6,11) = -1;
g0(6,5) = phiHstar;
g0(6,7) = phiFstar;

% Home Resource Constraint
g0(7,13) = -1;
g0(7,1) = Cbar*phiH;
g0(7,3) = Cbar*(1-nn)/nn*phiHstar;
g0(7,15) = eta*(Cbar+Ibar)*(1-nn)/nn*phiHstar;
g0(7,16) = -eta*(Cbar+Ibar)*(phiH+(1-nn)/nn*phiHstar);
g0(7,18) = 1;
g0(7,32) = Ibar*phiH;
g0(7,33) = Ibar*(1-nn)/nn*phiHstar;


% Foreign Resource Constraint
g0(8,14) = -1;
g0(8,1) = Cbar*nn/(1-nn)*phiF;
g0(8,3) = Cbar*phiFstar;
g0(8,15) = eta*(Cbar+Ibar)*phiFstar;
g0(8,16) = eta*(Cbar+Ibar)*(nn/(1-nn)*phiF+phiFstar)*phiH/phiF;
g0(8,19) = 1;
g0(8,32) = Ibar*nn/(1-nn)*phiF;
g0(8,33) = Ibar*phiFstar;

% Home Relative Price
g0(9,16) = 1;
g1(9,16) = 1;
g0(9,5) = -1;
g0(9,9) = 1;

% Real Exchange Rate
g0(10,15) = -1;
g0(10,16) = phiHstar-phiH/phiF*phiFstar;

% Taylor Rule
g0(11,17) = -1;
g1(11,17) = -rhoii;
g0(11,9) = (1-rhoii)*nn*phiPi;
g0(11,11) = (1-rhoii)*(1-nn)*phiPi;
g0(11,13) = (1-rhoii)*nn*phiY;
g0(11,14) = (1-rhoii)*(1-nn)*phiY;
g0(11,18) = (1-rhoii)*nn*phiG;
g0(11,19) = (1-rhoii)*(1-nn)*phiG;
psi(11,3) = 1;
g0(11,53) = (1-rhoii)*phiG;


% Home Government Spending
g0(12,18) = 1;
g1(12,18) = rhoG;
psi(12,1) = 1;

% Foreign Government Spending
g0(13,19) = 1;
g1(13,19) = rhoG;
psi(13,2) = 1;

% Expectation Error Equations
g0(14,1) = 1;
g1(14,2) = 1;
pi(14,1) = 1;

g0(15,3) = 1;
g1(15,4) = 1;
pi(15,2) = 1;

g0(16,5) = 1;
g1(16,6) = 1;
pi(16,3) = 1;

g0(17,7) = 1;
g1(17,8) = 1;
pi(17,4) = 1;

g0(18,9) = 1;
g1(18,10) = 1;
pi(18,5) = 1;

g0(19,11) = 1;
g1(19,12) = 1;
pi(19,6) = 1;

% Home Nominal Output
g0(20,20) = -1;
g0(20,13) = 1;
g0(20,5) = 1;

% Foreign Nominal Output
g0(21,21) = -1;
g0(21,14) = 1;
g0(21,7) = 1;

% Home production function
g0(22,22) = -aa;
g0(22,13) = 1;
g0(22,30) = -(1-aa);
g1(22,51) = mou;

% Foreign production function
g0(23,23) = -aa;
g0(23,14) = 1;
g0(23,31) = -(1-aa);
g1(23,52) = mou;

% Home production real wage
g0(24,24) = 1;
g0(24,22) = -nu^(-1);
g0(24,16) = 1;
g0(24,50) = -taubar/(1-taubar);

% Foreign production real wage
g0(25,25) = 1;
g0(25,23) = -nu^(-1);
g0(25,15) = -1;
g0(25,16) = -phiH/phiF;
g0(25,50) = -taubar/(1-taubar);


% Home marginal cost
g0(26,26) = 1;
g0(26,1) = -sigma^(-1)*psi_c;
g0(26,13) = -psi_v;
g0(26,16) = 1;
g0(26,38) = -psi_k;
g1(26,51) = -mou*psi_c*((1/nu)+1)/aa;

% Foreign marginal cost
g0(27,27) = 1;
g0(27,3) = -sigma^(-1)*psi_c;
g0(27,14) = -psi_v;
g0(27,15) = -psi_c;
g0(27,16) = -phiH/phiF;
g0(27,42) = -psi_k;
g1(27,52) = -mou*psi_c*((1/nu)+1)/aa;

% Home capital accumulation
g0(28,28) = 1;
g1(28,28) = (1-delta);
g0(28,32) = -delta;

% Foreign capital accumulation
g0(29,29) = 1;
g1(29,29) = (1-delta);
g0(29,33) = -delta;

% Home capital input
g0(30,30) = 1;
g1(30,28) = 1;
g0(30,34) = -1;

% Foreign capital input
g0(31,31) = 1;
g1(31,29) = 1;
g0(31,35) = -1;

% Home investment
g0(32,36) = 1;
g0(32,32) = -kappa_i*(1+beta);
g1(32,32) = -kappa_i;
g0(32,48) = beta*kappa_i;
g0(32,1) = sigma_c^(-1);
g0(32,22) = -sigma_l^(-1);

% Foreign investment
g0(33,37) = 1;
g0(33,33) = -kappa_i*(1+beta);
g1(33,33) = -kappa_i;
g0(33,49) = beta*kappa_i;
g0(33,3) = sigma_c^(-1);
g0(33,23) = -sigma_l^(-1);

% Home capital utilization
g0(34,34) = sigma_a;
g0(34,38) = -1;

% Foreign capital utilization
g0(35,35) = sigma_a;
g0(35,42) = -1;
g0(35,15) = 1;

% Home shadow value of installed capital
g0(36,36) = -1;
g0(36,39) = beta*(1-delta);
g0(36,41) = (1-beta*(1-delta));
g0(36,2) = -sigma_c^(-1)*(1-beta*(1-delta));
g0(36,46) = sigma_l^(-1)*(1-beta*(1-delta));

% Foreign shadow value of installed capital
g0(37,37) = -1;
g0(37,40) = beta*(1-delta);
g0(37,43) = (1-beta*(1-delta));
g0(37,10) = (1-beta*(1-delta));
g0(37,15) = -(1-beta*(1-delta));
g0(37,12) = -(1-beta*(1-delta));
g0(37,4) = -sigma_c^(-1)*(1-beta*(1-delta));
g0(37,47) = sigma_l^(-1)*(1-beta*(1-delta));

% Home capital demand
g0(38,38) = -1;
g0(38,22) = nu^(-1)+1;
g0(38,30) = -1;

% Expectations Errors
g0(39,36) = 1;
g1(39,39) = 1;
pi(39,7) = 1;

g0(40,37) = 1;
g1(40,40) = 1;
pi(40,8) = 1;

g0(41,38) = 1;
g1(41,41) = 1;
pi(41,9) = 1;

% Foreign capital demand
g0(42,42) = -1;
g0(42,23) = nu^(-1)+1;
g0(42,31) = -1;
g0(42,15) = 1;

% Expectations Error
g0(43,42) = 1;
g1(43,43) = 1;
pi(43,10) = 1;

g0(44,34) = 1;
g1(44,44) = 1;
pi(44,11) = 1;

g0(45,35) = 1;
g1(45,45) = 1;
pi(45,12) = 1;

g0(46,22) = 1;
g1(46,46) = 1;
pi(46,13) = 1;

g0(47,23) = 1;
g1(47,47) = 1;
pi(47,14) = 1;

g0(48,32) = 1;
g1(48,48) = 1;
pi(48,15) = 1;

g0(49,33) = 1;
g1(49,49) = 1;
pi(49,16) = 1;

% taxes

% No Taxes
g0(50,50) = 1;
% Balanced Budget
if BalancedBudget == 1
   g0(50,50) = 1;
   g0(50,24) = nn;
   g0(50,25) = 1-nn;
   g0(50,22) = nn;
   g0(50,23) = (1-nn);
   g0(50,18) = -nn;
   g0(50,19) = -(1-nn);
   g0(50,5) = -nn;
   g0(50,7) = -(1-nn);
end

% Central Government Spending
g0(51,53) = -1;
g0(51,18) = (1-xsi)*nn;
g0(51,19) = (1-xsi)*(1-nn);
g0(51,5) = (1-xsi)*nn;
g0(51,7) = (1-xsi)*(1-nn);


% definition public output at home
lamBBUH = lamda(ij)*(xsi*nn/(1-xsi))^pssi(ik);
lamBBUF = lamda(ij)*(xsi*(1-nn)/(1-xsi))^pssi(ik);

lamBBH = lamda(ij)*(xsi*nn/(1-xsi))^pssi(ik)+(1-lamda(ij))*omega^pssi(ik);
lamBBF = lamda(ij)*(xsi*(1-nn)/(1-xsi))^pssi(ik)+(1-lamda(ij))*omega^pssi(ik);

g0(52,51) = -1;
g0(52,18) = lamBBUH/lamBBH;
g0(52,53) = ((1-lamda(ij))*omega^pssi(ik))/lamBBH;

% definition public output abroad
g0(53,52) = -1;
g0(53,19) = lamBBUF/lamBBF;
g0(53,53) = ((1-lamda(ij))*omega^pssi(ik))/lamBBF;
%
%
% defintion  capital per hour 
g0(54,54) = 1;
g0(54,28) = -1;
g0(54,22) = 1;
% defintion capital per hour 
g0(55,55) = 1;
g0(55,29) = -1;
g0(55,23) = 1;


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Run Gensys
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

[G1,C,impact,fmat,fwt,ywt,gev,eu] = gensys(g0,g1,cc,psi,pi);

% Shock to Goverment Spending
shock = [1;0;0];

% Impulse Response
irf1 = VarImpulse(G1,impact,shock,period);

    gl5 = irf1(:,22)';    % responses of home employment
    gl6 = irf1(:,23)';    % response of foreign employment
    gl7 = irf1(:,15)';    % response of real exchange rate
    gl8 = irf1(:,17)';    % response of nominal interest rate
    gl9 = irf1(:,51)';    % response of public good
    gl10 = irf1(:,52)';   % response of public good
    gl11= irf1(:,9)';     % response of domestic CPI inflation 
    gl12 = irf1(:,11)';   % response of foreign CPI inflation
    gl15 = irf1(:,13)';   % response of  output
    gl16 = irf1(:,14)';   % response of output abroad
    gl17 = irf1(:,24)';   % response of wage at home
    gl18 = irf1(:,25)';   % response of wage abroad
    gl19 = irf1(:,5)';    % response of domestic inflation at home
    gl20 = irf1(:,7)';    % response of domestic inflation abroad
    gl25 = irf1(:,1)';    % response of consumption at home
    gl26 = irf1(:,3)';    % response of consumption abroad
    gl28 = irf1(:,26)';   % home marginal costs
    gl29 = irf1(:,27)';   % foreign marginal costs
    gl30 = irf1(:,30)';   % home capital input
    gl31 = irf1(:,31)';   % foreign capital input
    gl27 = irf1(:,50)';   % response of tax rate
    gl34 = irf1(:,53)';   % central government spending
    gl36 = irf1(:,18)';   % home government spending
    gl37 = irf1(:,19)';   % foreign governemnt spending
    gl38 = irf1(:,34)';   % uilization
    gl39 = irf1(:,35)';   % foreign util
    gl40 = irf1(:,28)';   % installed home capital
    gl41 = irf1(:,29)';   % installed foreign capital
    gl42 = irf1(:,30)';   % home capital input (as oppose to installed capital)))
    gl43 = irf1(:,31)';   % home capital input (as oppose to installed capital)))
    gl44 = irf1(:,32)';   % home investment
    gl45 = irf1(:,33)';   % foreign investment
    gl46 = (irf1(:,13)-irf1(:,22))';   % home labor productivity
    gl47 = (irf1(:,14)-irf1(:,23))';   % foreign labor productivity



% Shock to Goverment Spending
shock = [1;0;0];

% Impulse Response
irf2 = VarImpulse(G1,impact,shock,period);

    gls5 = irf2(:,22)';    % responses of home employment
    gls6 = irf2(:,23)';    % response of foreign employment
    gls7 = irf2(:,15)';    % response of real exchange rate
    gls8 = irf2(:,17)';    % response of nominal interest rate
    gls9 = irf2(:,51)';    % response of public good
    gls10 = irf2(:,52)';   % response of public good
    gls11= irf2(:,9)';     % response of domestic CPI inflation 
    gls12 = irf2(:,11)';   % response of foreign CPI inflation
    gls15 = irf2(:,13)';   % response of output
    gls16 = irf2(:,14)';   % response of output abroad
    gls17 = irf2(:,24)';   % response of wage at home
    gls18 = irf2(:,25)';   % response of wage abroad
    gls19 = irf2(:,5)';    % response of domestic inflation at home
    gls20 = irf2(:,7)';    % response of domestic inflation abroad
    gls25 = irf2(:,1)';    % response of consumption at home
    gls26 = irf2(:,3)';    % response of consumption abroad
    gls28 = irf2(:,26)';   % home marginal costs
    gls29 = irf2(:,27)';   % foreign marginal costs
    gls30 = irf2(:,30)';   % home capital input
    gls31 = irf2(:,31)';   % foreign capital input
    gls27 = irf2(:,50)';   % response of tax rate
    gls34 = irf2(:,53)';   % central government spending
    gls36 = irf2(:,18)';   % home government spending
    gls37 = irf2(:,19)';   % foreign governemnt spending
    gls38 = irf2(:,34)';   % utilization
    gls39 = irf2(:,35)';   % foreign util
    gls40 = irf2(:,28)';   % installed home capital
    gls41 = irf2(:,29)';   % installed foreign capital
    gls44 = irf2(:,32)';   % home investment
    gls45 = irf2(:,33)';   % foreign investment
    gls46 = (irf2(:,13)-irf2(:,22))';   % home labor productivity
    gls47 = (irf2(:,14)-irf2(:,23))';   % foreign labor productivity

% %%%%%%%%%%%%%%% IRFs multipliers %%%%%%%%%%%%%%%%%%%%%%%%%%
 ydG = gl15';
 govG = gl36';
 govGS = gls37';
 ydSG = gls16';
 ydGfor = gl16';
 govfor = gl37';
 ydGSfor = gls15';
 govSfor = gls36';
 KdG  = gl40';
 KdSG = gl41';
 % %
cummulG=[];
cummulCG=[];
cummulGS=[];

 kcumsumG2 = KdG(2)/govG(2);
 ycumsumG2= ydG(2)/govG(2);
 
 SENS_reg_imp(ik,ij)=ycumsumG2;
 SENS_reg_impk(ik,ij)=kcumsumG2;
 
 for t=3:NIR
    ycumsumG(t)= ydG(t)/(1+(1/beta))^(t-1);
    kcumsumG(t)= KdG(t)/(1+(1/beta))^(t-1);
    gcumsumG(t) = govG(t)/(1+(1/beta))^(t-1);
    ycumsumGS(t)=ydSG(t)/(1+(1/beta))^(t-1);
    gcumsumGS(t)=govGS(t)/(1+(1/beta))^(t-1);
    end;

cummultiplierG = (ydG(2)+sum(ycumsumG))/(govG(2)+sum(gcumsumG));
cummultiplierGS = (ydSG(2)+sum(ycumsumGS))/(govGS(2)+sum(gcumsumGS));
cummultiplierK = (KdG(2)+sum(kcumsumG))/(govG(2)+sum(gcumsumG));

SENS_reg_cum(ik,ij)=cummultiplierG;
SENS_reg_cumk(ik,ij)=cummultiplierK;


SENS_reg_cum(ik,ij)=cummultiplierG;
SENS_reg_cumk(ik,ij)=cummultiplierK;

%fprintf('Regional impact and cummulative multipliers')

 YcummulCG2 = (nn*ydG(2)+(1-nn)*ydSG(2))/(nn*govG(2)+(1-nn)*govGS(2));
 KcummulCG2 = (nn*KdG(2)+(1-nn)*KdSG(2))/(nn*govG(2)+(1-nn)*govGS(2));
SENS_union_imp(ik,ij) =YcummulCG2;%*(1/((1-xsi)*(nn*Gbar+(1-nn)*Gbar))); 
SENS_union_impk(ik,ij) =KcummulCG2;%*(1/((1-xsi)*(nn*Gbar+(1-nn)*Gbar))); 

for t=3:NIR
      YcummulCG(t) = (nn*ydG(t)+(1-nn)*ydSG(t))/(1+(1/beta))^(t-1);
      KcummulCG(t) = (nn*KdG(t)+(1-nn)*KdSG(t))/(1+(1/beta))^(t-1);
      GcummulCG(t) = (nn*govG(t)+(1-nn)*govGS(t))/(1+(1/beta))^(t-1);         
end
cummultiplierCK = (nn*KdG(2)+(1-nn)*KdSG(2)+sum(KcummulCG2))/(nn*govG(2)+(1-nn)*govGS(2)+sum(GcummulCG));
cummultiplierCG = (nn*ydG(2)+(1-nn)*ydSG(2)+sum(YcummulCG))/(nn*govG(2)+(1-nn)*govGS(2)+sum(GcummulCG));%*(1/((1-xsi)*(nn*Gbar+(1-nn)*Gbar)));

SENS_union_cum(ik,ij) = cummultiplierCG;
SENS_union_cumk(ik,ij) = cummultiplierCK;

%fprintf('Aggregate impact and cummulative multipliers')

fprintf('\n')
end

% title ('Multipliers and local autonomy')
% % 
% % 
figure(1);    
plot(lamda,SENS_reg_imp(ik,:))
legend('psi=-0.5')
xlabel('degree of local autonomy')
ylabel('output multipliers')
axis tight
hold on;

figure(2);    
plot(lamda,SENS_reg_impk(ik,:))
legend('psi=-0.5')
xlabel('degree of local autonomy')
ylabel('capital multipliers')
axis tight
hold on;


end;



