******
***           ALL ESTIMATES ON REGIONAL VARIABLES
***
***                       TABLES
***   Table 2 Baseline, Table 3A Controlling for Institutional Quality
***   Table 3A Controlling for Institutional Quality
***   Table 3B: Other Potential Confounders: Controlling for Lagged Output, Trade Openness, and Population Density
***   Table 4 State Depencence: Expansions vs. contractions
***   Table 5 State Dependence: Slack vs. Tight Labor Market
***   Table 6: National multiplier 
***   Table 7: Effects on capital and TFP
***
***   Appendix: estimates of equation (2)
***   
***                       FIGURES          
***   
***   Figure 2 The Geographic Cross-Sectional Government Spending Multiplier and Local Autonomy
***   Figure 3A: expansions vs. contractions
***   Figure 3B: slack vs. tight labor market
***   Figure 4: National vs. geographic cross-sectional multipliers
***   Figure 5: Effects on capital and TFP
***   
******
***
***   Change it to the location of regional_data.dta
***
*** cd "<location of regional_data.dta>"
***
************
use "regional_data.dta", clear

tsset NUTSCodeNum year

*Table 2 Baseline
xtivreg2 lgva_ph lgva_nm_ph_res lgva_nm_ph_LAI_res LAI (L.lgva_ph=DL.lgva_ph) time* if NUTSLevel!=0 , fe  cluster(NUTSCodeNum)
replace marg2_short=(_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/0.22
replace marg2_cum=((_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/(1-_b[L.lgva_ph]))/0.22
sum marg2_short marg2_cum, detail


*Figure 2
graph set window fontface "Times New Roman"
graph twoway (line marg2_short LAI,sort lwidth(thick) lpattern(solid) ) (line marg2_cum LAI, sort  lwidth(thick) lpattern(dash_dot)), name(figure2, replace)
*graph export  "figure2.eps", name(figure2) as(eps) fontface("Times New Roman") replace


*Table 3: additional controls

*Table 3A Controlling for Institutional Quality
xtivreg2 lgva_ph lgva_nm_ph_res lgva_nm_ph_LAI_res LAI lgva_nm_ph_res_EQI EQI (L.lgva_ph=DL.lgva_ph) time* if NUTSLevel!=0  , fe cluster(NUTSCodeNum)
replace marg31_short=(_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/0.22
replace marg31_cum=((_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/(1-_b[L.lgva_ph]))/0.22
sum marg31_short marg31_cum, detail


*Table 3B: Other Potential Confounders: Controlling for Lagged Output, Trade Openness, and Population Density
xtivreg2 lgva_ph lgva_nm_ph_res lgva_nm_ph_LAI_res lgva_nm_ph_res_gva_ph lgva_nm_ph_res_trade lgva_nm_ph_res_pop  popden trade_gdp LAI (L.lgva_ph=DL.lgva_ph) time* if NUTSLevel!=0 , fe  cluster(NUTSCodeNum)
replace marg32_short=(_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/0.22
replace marg32_cum=((_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/(1-_b[L.lgva_ph]))/0.22
sum marg32_short marg32_cum, detail


*Table 4 State Depencence: Expansions vs. contractions

* contractions
xtivreg2 lgva_ph lgva_nm_ph_res lgva_nm_ph_LAI_res LAI (L.lgva_ph=DL.lgva_ph) time*  if NUTSLevel!=0  &res<0, fe cluster(NUTSCodeNum)
replace marg4_contract_short=(_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/0.22
replace marg4_contract_cum=((_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/(1-_b[L.lgva_ph]))/0.22
sum marg4_contract_short marg4_contract_cum, detail
* expansions
xtivreg2 lgva_ph lgva_nm_ph_res lgva_nm_ph_LAI_res LAI (L.lgva_ph=DL.lgva_ph) time*  if NUTSLevel!=0   &res>0, fe cluster(NUTSCodeNum)
replace marg4_expand_short=(_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/0.22
replace marg4_expand_cum=((_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/(1-_b[L.lgva_ph]))/0.22
sum marg4_expand_short marg4_expand_cum, detail

*Figure 3A: expansions vs. contractions
graph twoway  (line marg4_contract_short LAI,sort lwidth(thick) lpattern(solid)) (line marg4_expand_short LAI,sort  lwidth(thick) lpattern(dash_dot)), name(figure3a, replace)
*graph export  "figure3a.eps", name(figure3a) as(eps) fontface("Times New Roman") replace

**Table 5 State Dependence: Slack vs. Tight Labor Market

*slack labor market
xtivreg2 lgva_ph lgva_nm_ph_res lgva_nm_ph_LAI_res LAI (L.lgva_ph=DL.lgva_ph) time* if NUTSLevel!=0 & laborslack<0.43 , fe cluster(NUTSCodeNum)
replace marg5_slack_short=(_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/0.22
replace marg5_slack_cum=((_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/(1-_b[L.lgva_ph]))/0.22
sum marg5_slack_short marg5_slack_cum, detail

sum margloose_short margloose_cumulative, detail


*tight labor market
xtivreg2 lgva_ph lgva_nm_ph_res lgva_nm_ph_LAI_res LAI (L.lgva_ph=DL.lgva_ph) time* if NUTSLevel!=0 & laborslack>0.43 , fe cluster(NUTSCodeNum)
replace marg5_tight_short=(_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/0.22
replace marg5_tight_cum=((_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/(1-_b[L.lgva_ph]))/0.22
sum marg5_tight_short marg5_tight_cum, detail

*Figure 3B: slack vs. tight labor market
graph twoway (line marg5_slack_short LAI ,sort lwidth(thick) lpattern(solid)) (line marg5_tight_short LAI,sort  lwidth(thick) lpattern(dash_dot)), name(figure3b, replace)
*graph export  "figure3b.eps", name(figure3b) as(eps) fontface("Times New Roman") replace

*Table 6: National multiplier 

xtivreg2 lgva_ph lgva_nm_ph_res lgva_nm_ph_LAI_res LAI (L.lgva_ph=L3.lgva_ph) time* if countrylevel==1, fe cluster(NUTSCodeNum)
replace marg6_country_short=(_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/0.22
replace marg6_country_cum=((_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/(1-_b[L.lgva_ph]))/0.22
sum marg6_country_short marg6_country_cum, detail


*Figure 4: National vs. geographic cross-sectional multipliers
graph twoway (line marg6_country_short LAI,sort lwidth(thick) lpattern(solid) ) (line marg2_short LAI, sort  lwidth(thick) lpattern(dash_dot)), name(figure4a, replace) 
graph twoway (line marg6_country_cum LAI, sort lwidth(thick) lpattern(solid)) (line marg2_cum LAI, sort  lwidth(thick) lpattern(dash_dot)), name(figure4b, replace) 
*graph export  "figure4a.eps", name(figure4a) as(eps) fontface("Times New Roman") replace
*graph export  "figure4b.eps", name(figure4b) as(eps) fontface("Times New Roman") replace

*Table 7: Effects on capital and TFP
xtivreg2 lk (L.lk=DL.lk) lgva_nm_ph_res lgva_nm_ph_LAI_res LAI  time* if NUTSLevel!=0  ,fd cluster(NUTSCodeNum)
replace marg_capital=_b[D.lgva_nm_ph_res]+_b[D.lgva_nm_ph_LAI_res]*LAI
replace marg_capital_cum=(_b[D.lgva_nm_ph_res]+_b[D.lgva_nm_ph_LAI_res]*LAI)/(1-_b[DL.lk])
sum marg_capital marg_capital_cum , detail


xtivreg2 ltfp2 (L.ltfp2=DL.ltfp2) lgva_nm_ph_res lgva_nm_ph_LAI_res LAI  time* if NUTSLevel!=0 &y==1  , fe cluster(NUTSCodeNum)
replace marg_tfp2=_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI
replace marg_tfp_cum2=(_b[lgva_nm_ph_res]+_b[lgva_nm_ph_LAI_res]*LAI)/(1-_b[L.ltfp])
sum marg_tfp2 marg_tfp_cum2, detail

*Figure 5: Effects on capital and TFP
graph twoway (line marg_tfp2 LAI )  (line marg_capital LAI ), name(figure5, replace)
*graph export  "figure5.eps", name(figure5) as(eps) fontface("Times New Roman") replace

******************Appendix
**estimates of equation (2)


xtivreg2 lgva_nm_ph  (lgva_ph = loil )  time* if NUTSLevel!=0 &LAI!=.&L.lgva_ph!=. &DL.lgva_ph!=. , fe  cluster(NUTSCodeNum)
xtivreg2 lgva_nm_ph_LAI (lgva_ph = loil )  time*, fe robust








